@@ -157,6 +157,9 @@ class Config:
 
     SCIPION_CWD = _get('SCIPION_CWD', os.path.abspath(os.getcwd()))
 
+    # Refresh the displayed runs with a thread
+    SCIPION_GUI_REFRESH_IN_THREAD = _get('SCIPION_GUI_REFRESH_IN_THREAD', 'False')
+
     try:
         VIEWERS = ast.literal_eval(_get('VIEWERS', "{}"))
     except Exception as e:
@@ -259,6 +262,11 @@ class Config:
         os.environ[SCIPION_DEBUG] = str(newValue)
         os.environ[SCIPION_DEBUG_NOCLEAN] = str(newValue)
 
+    @classmethod
+    def refreshInThreads(cls):
+        from .utils import strToBoolean
+        return strToBoolean(cls.SCIPION_GUI_REFRESH_IN_THREAD)
+
     @classmethod
     def getExternalJsonTemplates(cls):
         return os.path.dirname(cls.SCIPION_CONFIG)
