@@ -229,10 +229,12 @@ class ProjectWindow(ProjectBaseWindow):
         
     def _loadWorkflow(self, obj):
         try:
+            self.getViewWidget().info('Importing the workflow...')
             self.project.loadProtocols(obj.getPath())
-            self.getViewWidget().updateRunsGraph(True, reorganize=True)
+            self.getViewWidget().updateRunsGraph(True, reorganize=False)
+            self.getViewWidget().cleanInfo()
         except Exception as ex:
-            self.showError(str(ex))
+            self.showError(str(ex), exception=ex)
             
     def onImportWorkflow(self):
         FileBrowserWindow("Select workflow .json file",
@@ -245,7 +247,7 @@ class ProjectWindow(ProjectBaseWindow):
         WorkflowRepository().search()
 
     def onExportTreeGraph(self):
-        runsGraph = self.project.getRunsGraph(refresh=True)
+        runsGraph = self.project.getRunsGraph()
         useId = not pwutils.envVarOn('SCIPION_TREE_NAME')
         dotStr = runsGraph.printDot(useId=useId)
         with tempfile.NamedTemporaryFile(suffix='.gv', mode="w") as dotFile:
