@@ -132,6 +132,14 @@ def prettyDelta(timedelta):
     """ Remove the milliseconds of the timedelta. """
     return str(timedelta).split('.')[0]
 
+class UtcConverter:
+    """ Class to make date conversions to utc"""
+    utc_delta = datetime.utcnow() - datetime.now()
+
+    def __call__(cls, t):
+        return t + cls.utc_delta
+# Use to_utc like a function: to_utc(date)
+to_utc = UtcConverter()
 
 def prettyLog(msg):
     print(cyan(prettyTime(datetime.now(), secs=True)), msg)
@@ -149,12 +157,16 @@ class Timer(object):
     def toc(self, message='Elapsed:'):
         print(message, self.getElapsedTime())
 
+    def getToc(self):
+        return prettyDelta(self.getElapsedTime())
+
     def __enter__(self):
         self.tic()
 
     def __exit__(self, type, value, traceback):
         self.toc()
 
+
 def timeit(func):
     """ Decorator function to have a simple measurement
     of the execution time of a given function.
@@ -676,6 +688,18 @@ class Environ(dict):
         else:
             print("Some paths do not exist in: % s" % libraryPath)
 
+    def setPrepend(self, prepend):
+        """ Use this method to set a prepend string that will be added at
+        the beginning of any command that will be run in this environment.
+        This can be useful for example when 'modules' need to be loaded and
+        a simple environment variables setup is not enough.
+        """
+        setattr(self, '__prepend', prepend)
+
+    def getPrepend(self):
+        """ Return if there is any prepend value. See setPrepend function. """
+        return getattr(self, '__prepend', '')
+
 
 def existsVariablePaths(variableValue):
     """ Check if the path (or paths) in variableValue exists.
@@ -699,7 +723,10 @@ def environAdd(varName, newValue, valueFirst=False):
 def envVarOn(varName, env=None):
     """ Is variable set to True in the environment? """
     v = env.get(varName) if env else os.environ.get(varName)
-    return v is not None and v.lower() in ['true', 'yes', 'on', '1']
+    return strToBoolean(v)
+
+def strToBoolean(string):
+    return string is not None and string.lower() in ['true', 'yes', 'on', '1']
 
 
 def getMemoryAvailable():
